@@ -12,6 +12,7 @@
 #include <X11/Xatom.h>
 
 #include "theme-common.h"
+#include "wm-common.h"
 #include "capplet-util.h"
 #include "eggcellrendererkeys.h"
 #include "activate-settings-daemon.h"
@@ -107,149 +108,7 @@ typedef struct
   guint gconf_cnxn;
 } KeyEntry;
 
-static void reload_key_entries (GladeXML *dialog);
-
-/* Our WM Window */
-static Window wm_window = None;
-
-static char *
-get_wm_name (void)
-{
-  Atom utf8_string, atom, type;
-  int result;
-  char *retval;
-  int format;
-  gulong nitems;
-  gulong bytes_after;
-  guchar *val;
-  
-  if (wm_window == None)
-      return NULL;
-  
-  utf8_string = XInternAtom (GDK_DISPLAY (), "UTF8_STRING", False);
-  atom = XInternAtom (GDK_DISPLAY (), "_NET_WM_NAME", False);
-  
-  gdk_error_trap_push ();
-  
-  result = XGetWindowProperty (GDK_DISPLAY (),
-			       wm_window,
-			       atom,
-			       0, G_MAXLONG,
-			       False, utf8_string,
-			       &type, &format, &nitems,
-			       &bytes_after, (guchar **)&val);
-
-  if (gdk_error_trap_pop () || result != Success)
-    return NULL;
-
-  if (type != utf8_string ||
-      format != 8 ||
-      nitems == 0)
-    {
-      if (val)
-	XFree (val);
-      return NULL;
-    }
-
-  if (!g_utf8_validate (val, nitems, NULL))
-    {
-      XFree (val);
-      return NULL;
-    }
-
-  retval = g_strndup (val, nitems);
-
-  XFree (val);
-
-  return retval;
-}
-
-static gboolean
-is_metacity_running (void)
-{
-  char *wm_name;
-
-  wm_name = get_wm_name ();
-  
-  if (wm_name &&
-      strcmp (wm_name, "Metacity") == 0)
-    {
-      g_free (wm_name);
-      return TRUE;
-    }
-
-  g_free (wm_name);
-  return FALSE;
-}
-
-static void
-update_wm_window (void)
-{
-  Window *xwindow;
-  Atom type;
-  gint format;
-  gulong nitems;
-  gulong bytes_after;
-  
-  XGetWindowProperty (GDK_DISPLAY (), GDK_ROOT_WINDOW (),
-		      XInternAtom (GDK_DISPLAY (), "_NET_SUPPORTING_WM_CHECK", False),
-		      0, G_MAXLONG, False, XA_WINDOW, &type, &format,
-		      &nitems, &bytes_after, (guchar **) &xwindow);
-
-  if (type != XA_WINDOW)
-    {
-      wm_window = None;
-      return;
-    }
-
-  gdk_error_trap_push ();
-  XSelectInput (GDK_DISPLAY (), *xwindow, StructureNotifyMask | PropertyChangeMask);
-  XSync (GDK_DISPLAY (), False);
-  
-  if (gdk_error_trap_pop ())
-    {
-      XFree (xwindow);
-      wm_window = None;
-      return;
-    }
-
-  wm_window = *xwindow;
-  XFree (xwindow);
-}
-
-static GdkFilterReturn 
-wm_window_event_filter (GdkXEvent *xev,
-			GdkEvent  *event,
-			gpointer   data)
-{
-  XEvent *xevent = (XEvent *)xev;
-
-  if ((xevent->type == DestroyNotify &&
-       wm_window != None && xevent->xany.window == wm_window) ||
-      (xevent->type == PropertyNotify &&
-       xevent->xany.window == GDK_ROOT_WINDOW () &&
-       xevent->xproperty.atom == (XInternAtom (GDK_DISPLAY (),  "_NET_SUPPORTING_WM_CHECK", False))) ||
-      (xevent->type == PropertyNotify &&
-       wm_window != None && xevent->xany.window == wm_window &&
-       xevent->xproperty.atom == (XInternAtom (GDK_DISPLAY (), "_NET_WM_NAME", False))))
-    {
-      update_wm_window ();
-      reload_key_entries (data);
-    }
-  
-  return GDK_FILTER_CONTINUE;
-}
-
-static void
-initialize_wm_handling (GladeXML *dialog)
-{
-  gdk_window_add_filter (NULL, wm_window_event_filter, dialog);
-
-  update_wm_window ();
-  
-  XSelectInput (GDK_DISPLAY (), GDK_ROOT_WINDOW (), PropertyChangeMask);
-  XSync (GDK_DISPLAY (), False);
-}
+static void reload_key_entries (gpointer wm_name, GladeXML *dialog);
 
 static void
 menu_item_activate (GtkWidget *menu_item,
@@ -277,8 +136,16 @@ make_key_theme_menu_item (const gchar *key_theme)
 {
   GtkWidget *retval;
 
-  retval = gtk_menu_item_new_with_label (key_theme);
-  g_object_set_data_full (G_OBJECT (retval), LABEL_DATA, g_strdup (key_theme), g_free);
+  if (!strcmp (key_theme, "Default"))
+    {
+      retval = gtk_menu_item_new_with_label ("GNOME Default");
+      g_object_set_data_full (G_OBJECT (retval), LABEL_DATA, g_strdup ("Default"), g_free);
+    }
+  else
+    {
+      retval = gtk_menu_item_new_with_label (key_theme);
+      g_object_set_data_full (G_OBJECT (retval), LABEL_DATA, g_strdup (key_theme), g_free);
+    }
   g_signal_connect (G_OBJECT (retval), "activate", G_CALLBACK (menu_item_activate), NULL);
   gtk_widget_show (retval);
 
@@ -363,6 +230,28 @@ accel_set_func (GtkTreeViewColumn *tree_column,
 		  NULL);
 }
 
+static gboolean
+keybinding_key_changed_foreach (GtkTreeModel *model,
+				GtkTreePath  *path,
+				GtkTreeIter  *iter,
+				gpointer      user_data)
+{
+  KeyEntry *key_entry;
+  KeyEntry *tmp_key_entry;
+
+  key_entry = (KeyEntry *)user_data;
+  gtk_tree_model_get (key_entry->model, iter,
+		      KEYENTRY_COLUMN, &tmp_key_entry,
+		      -1);
+
+  if (key_entry == tmp_key_entry)
+    {
+      gtk_tree_model_row_changed (key_entry->model, path, iter);
+      return TRUE;
+    }
+  return FALSE;
+}
+
 static void
 keybinding_key_changed (GConfClient *client,
 			guint        cnxn_id,
@@ -371,33 +260,15 @@ keybinding_key_changed (GConfClient *client,
 {
   KeyEntry *key_entry;
   const gchar *key_value;
-  GtkTreePath *path;
-  GtkTreeIter iter;
-  gboolean valid;
-  
+
   key_entry = (KeyEntry *)user_data;
   key_value = gconf_value_get_string (entry->value);
 
   binding_from_string (key_value, &key_entry->keyval, &key_entry->mask);
   key_entry->editable = gconf_entry_get_is_writable (entry);
 
-  path = gtk_tree_path_new_first ();
-  for (valid = gtk_tree_model_get_iter_first (key_entry->model, &iter);
-       valid;
-       valid = gtk_tree_model_iter_next (key_entry->model, &iter))
-    {
-      KeyEntry *tmp_key_entry;
-
-      gtk_tree_model_get (key_entry->model, &iter,
-			  KEYENTRY_COLUMN, &tmp_key_entry,
-			  -1);
-      if (tmp_key_entry == key_entry)
-	{
-	  gtk_tree_model_row_changed (key_entry->model, path, &iter);
-	}
-      gtk_tree_path_next (path);
-    }
-  gtk_tree_path_free (path);
+  /* update the model */
+  gtk_tree_model_foreach (key_entry->model, keybinding_key_changed_foreach, key_entry);
 }
 
 
@@ -575,23 +446,19 @@ append_keys_to_tree (GladeXML           *dialog,
     }
 
   if (i == 0)
-    {
-      gtk_widget_hide (WID ("shortcuts_frame"));
-    }
+      gtk_widget_hide (WID ("shortcuts_vbox"));
   else
-    {
-      gtk_widget_show (WID ("shortcuts_frame"));
-    }
+      gtk_widget_show (WID ("shortcuts_vbox"));
 }
 
 static void
-reload_key_entries (GladeXML *dialog)
+reload_key_entries (gpointer wm_name, GladeXML *dialog)
 {
   clear_old_model (dialog, WID ("shortcut_treeview"));
   
   append_keys_to_tree (dialog, _("Desktop"), desktop_key_list);
   
-  if (is_metacity_running ())
+  if (strcmp((char *) wm_name, WM_COMMON_METACITY) == 0)
     {
       append_keys_to_tree (dialog, _("Window Management"), metacity_key_list);
     }
@@ -603,7 +470,7 @@ key_entry_controlling_key_changed (GConfClient *client,
 				   GConfEntry  *entry,
 				   gpointer     user_data)
 {
-  reload_key_entries (user_data);
+  reload_key_entries (wm_common_get_current_window_manager(), user_data);
 }
 
 static void
@@ -653,6 +520,7 @@ accel_edited_callback (GtkCellRendererText *cell,
                        const char          *path_string,
                        guint                keyval,
                        GdkModifierType      mask,
+		       guint                keycode,
                        gpointer             data)
 {
   GtkTreeView *view = (GtkTreeView *)data;
@@ -689,7 +557,7 @@ accel_edited_callback (GtkCellRendererText *cell,
 				       GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
 				       GTK_MESSAGE_WARNING,
 				       GTK_BUTTONS_OK,
-				       "Error setting new accelerator in configuration database: %s\n",
+				       _("Error setting new accelerator in configuration database: %s\n"),
 				       err->message);
       gtk_dialog_run (GTK_DIALOG (dialog));
 
@@ -728,10 +596,10 @@ theme_changed_func (gpointer  uri,
 
       menu_item = make_key_theme_menu_item (info->name);
       if (!strcmp (info->name, "Default"))
-	/* Put default first, always */
-	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
+      /* Put default first, always */
+        gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
       else
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
+        gtk_menu_shell_append (GTK_MENU_SHELL (menu), menu_item);
     }
 
   gtk_widget_show (menu);
@@ -745,18 +613,78 @@ theme_changed_func (gpointer  uri,
   key_theme_changed (client, 0, entry, omenu);
 }
 
-static gboolean
-disable_collapsing_cb (GtkTreeView *tree_view, GtkTreeIter *iter, GtkTreePath *path)
+
+typedef struct
 {
+  GtkTreeView *tree_view;
+  GtkTreePath *path;
+} IdleData;
+
+static gboolean
+real_start_editing_cb (IdleData *idle_data)
+{
+  gtk_widget_grab_focus (GTK_WIDGET (idle_data->tree_view));
+  gtk_tree_view_set_cursor (idle_data->tree_view,
+			    idle_data->path,
+			    gtk_tree_view_get_column (idle_data->tree_view, 1),
+			    TRUE);
+
+  gtk_tree_path_free (idle_data->path);
+  g_free (idle_data);
+  return FALSE;
+}
+
+static gboolean
+start_editing_cb (GtkTreeView    *tree_view,
+		  GdkEventButton *event,
+		  GladeXML       *dialog)
+{
+  GtkTreePath *path;
+
+  if (event->window != gtk_tree_view_get_bin_window (tree_view))
+    return FALSE;
+
+  if (gtk_tree_view_get_path_at_pos (tree_view,
+				     (gint) event->x,
+				     (gint) event->y,
+				     &path, NULL,
+				     NULL, NULL))
+    {
+      IdleData *idle_data;
+
+      if (gtk_tree_path_get_depth (path) == 1)
+	{
+	  gtk_tree_path_free (path);
+	  return FALSE;
+	}
+
+      idle_data = g_new (IdleData, 1);
+      idle_data->tree_view = tree_view;
+      idle_data->path = path;
+      g_signal_stop_emission_by_name (G_OBJECT (tree_view), "button_press_event");
+      g_idle_add ((GSourceFunc) real_start_editing_cb, idle_data);
+    }
   return TRUE;
 }
 
+static void
+cb_dialog_response (GtkWidget *widget, gint response_id, gpointer data)
+{
+	if (response_id == GTK_RESPONSE_HELP)
+		capplet_help (GTK_WINDOW (widget),
+			      "wgoscustdesk.xml",
+			      "goscustdesk-39");
+	else
+		gtk_main_quit ();
+}
+
 static void
 setup_dialog (GladeXML *dialog)
 {
   GConfClient *client;
   GList *key_theme_list;
   GtkCellRenderer *renderer;
+  GtkTreeViewColumn *column;
   GtkWidget *widget;
   gboolean found_keys = FALSE;
   GList *list;
@@ -785,7 +713,6 @@ setup_dialog (GladeXML *dialog)
       gtk_dialog_run (GTK_DIALOG (msg_dialog));
       gtk_widget_destroy (msg_dialog);
 
-      gtk_widget_hide (WID ("shortcut_hbox"));
     }
   else
     {
@@ -799,15 +726,18 @@ setup_dialog (GladeXML *dialog)
     }
 
 
-  g_signal_connect (WID ("shortcut_treeview"), "test_collapse_row",
-		    G_CALLBACK (disable_collapsing_cb), NULL),
+  g_signal_connect (GTK_TREE_VIEW (WID ("shortcut_treeview")),
+		    "button_press_event",
+		    G_CALLBACK (start_editing_cb), dialog),
 		    
-  gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (WID ("shortcut_treeview")),
-					       -1,
-					       _("_Action"),
-					       gtk_cell_renderer_text_new (),
-					       "text", DESCRIPTION_COLUMN,
-					       NULL);
+  column = gtk_tree_view_column_new_with_attributes (_("Action"),
+						     gtk_cell_renderer_text_new (),
+						     "text", DESCRIPTION_COLUMN,
+						     NULL);
+  gtk_tree_view_column_set_resizable (column, TRUE);
+
+  gtk_tree_view_append_column (GTK_TREE_VIEW (WID ("shortcut_treeview")), column);
+
   renderer = (GtkCellRenderer *) g_object_new (EGG_TYPE_CELL_RENDERER_KEYS,
 					       "editable", TRUE,
 					       NULL);
@@ -815,24 +745,28 @@ setup_dialog (GladeXML *dialog)
 		    "keys_edited",
                     G_CALLBACK (accel_edited_callback),
                     WID ("shortcut_treeview"));
-  gtk_tree_view_insert_column_with_data_func (GTK_TREE_VIEW (WID ("shortcut_treeview")),
-					      -1, _("_Shortcut"),
-					      renderer,
-					      accel_set_func, NULL, NULL);
+
+  column = gtk_tree_view_column_new_with_attributes (_("Shortcut"), renderer, NULL);
+  gtk_tree_view_column_set_cell_data_func (column, renderer, accel_set_func, NULL, NULL);
+  gtk_tree_view_column_set_resizable (column, TRUE);
+
+  gtk_tree_view_append_column (GTK_TREE_VIEW (WID ("shortcut_treeview")), column);
+
   gconf_client_add_dir (client, "/apps/gnome_keybinding_properties", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
   gconf_client_add_dir (client, "/apps/metacity/general", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
   gconf_client_notify_add (client,
 			   "/apps/metacity/general/num_workspaces",
 			   (GConfClientNotifyFunc) &key_entry_controlling_key_changed,
 			   dialog, NULL, NULL);
-  
+
   /* set up the dialog */
-  reload_key_entries (dialog);
+  reload_key_entries (wm_common_get_current_window_manager(), dialog);
 
   widget = WID ("gnome-keybinding-dialog");
+  capplet_set_icon (widget, "keyboard-shortcut.png");
   gtk_widget_show (widget);
 
-  g_signal_connect (G_OBJECT (widget), "response", gtk_main_quit, NULL);
+  g_signal_connect (G_OBJECT (widget), "response", G_CALLBACK(cb_dialog_response), NULL);
   g_signal_connect (G_OBJECT (widget), "close", gtk_main_quit, NULL);
 }
 
@@ -847,14 +781,14 @@ main (int argc, char *argv[])
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  gnome_program_init (argv[0], VERSION, LIBGNOMEUI_MODULE, argc, argv,
+  gnome_program_init ("gnome-keybinding-properties", VERSION, LIBGNOMEUI_MODULE, argc, argv,
 		      GNOME_PARAM_APP_DATADIR, GNOMECC_DATA_DIR,
 		      NULL);
 
   activate_settings_daemon ();
 
   dialog = create_dialog ();
-  initialize_wm_handling (dialog);
+  wm_common_register_window_manager_change ((GFunc)(reload_key_entries), dialog);
   setup_dialog (dialog);
   
   gtk_main ();
