@@ -164,12 +164,16 @@ set_have_icons (GladeXML *dialog, gboolean value)
 {
   static char *menu_item_names[] = 
     {
-      "menu1",
+      "File Menu",
       "menu_item_1",
       "menu_item_2",
       "menu_item_3",
       "menu_item_4",
       "menu_item_5",
+      "edit1",
+      "cut1",
+      "copy1",
+      "paste1",
       NULL
     };
   
@@ -272,6 +276,7 @@ setup_dialog (GladeXML *dialog, GConfChangeSet *changeset)
   g_free (toolbar_style);
 
   gtk_window_set_resizable (GTK_WINDOW (widget), FALSE);
+  capplet_set_icon (widget, "behavior-capplet.png");
   gtk_widget_show_all (widget);
 }
 
@@ -296,7 +301,6 @@ main (int argc, char **argv)
 
   dialog = create_dialog ();
   setup_dialog (dialog, changeset);
-
   gtk_main ();
 
   return 0;
