@@ -44,6 +44,8 @@
 #include "gnome-settings-wm.h"
 #include "gnome-settings-accessibility-keyboard.h"
 #include "gnome-settings-screensaver.h"
+#include "gnome-settings-default-editor.h"
+#include "gnome-settings-keybindings.h"
 
 #include "GNOME_SettingsDaemon.h"
 
@@ -147,7 +149,9 @@ awake_impl (PortableServer_Servant servant,
 	    const CORBA_char      *service,
 	    CORBA_Environment     *ev)
 {
+#if 0
   printf ("I received an activate request for %s\n", service);
+#endif
   return TRUE;
 }
 
@@ -230,11 +234,13 @@ gnome_settings_daemon_new (void)
   gnome_settings_xsettings_init (client);
   gnome_settings_mouse_init (client);
   gnome_settings_keyboard_init (client);
-  gnome_settings_background_init (client);
   gnome_settings_sound_init (client);
   gnome_settings_wm_init (client);
   gnome_settings_accessibility_keyboard_init (client);
   gnome_settings_screensaver_init (client);
+  gnome_settings_default_editor_init (client);
+  gnome_settings_background_init (client);
+  gnome_settings_keybindings_init (client);
 
   for (list = directories; list; list = list->next)
     {
@@ -267,11 +273,14 @@ gnome_settings_daemon_new (void)
   gnome_settings_font_load (client);
   gnome_settings_xsettings_load (client);
   gnome_settings_mouse_load (client);
+  gnome_settings_keyboard_load (client);
   gnome_settings_sound_load (client);
-  gnome_settings_background_load (client);
   gnome_settings_wm_load (client);
   gnome_settings_accessibility_keyboard_load (client);
   gnome_settings_screensaver_load (client);
-  
+  gnome_settings_default_editor_load (client);
+  gnome_settings_background_load (client);
+  gnome_settings_keybindings_load (client);
+
   return G_OBJECT (daemon);
 }
